# Example: Escape Room

:::{escape-room}


puzzle: Rom 1
code: 144
Q: Koden til neste rom er gitt ved produktet nedenfor $$\lg (100) \cdot \ln \left(\dfrac{1}{e^2}\right) \cdot \log_2 (8) \cdot \lg \left(\dfrac{1}{\sqrt{100}}\right) \cdot \ln \left(e^4\right) \cdot \log_3 (27)$$


puzzle: Rom 2
code: 25
Q: Koden til neste rom er summen $$e^{2x_1} + e^{2x_2}$$ der $x_1$ og $x_2$ løser likningen $$e^{2x} - 7e^x + 12 = 0$$




puzzle: Rom 3
code: 865430
Q: Koden til neste rom er verdiene nedenfor plassert i synkende rekkefølge: $$\begin{align*}
& \lim_{x \to 0} \dfrac{e^{4x}-1}{x} \quad\quad \lim_{x \to 0} \dfrac{\ln(1+3x)}{x} \quad\quad \lim_{x \to 0} \dfrac{(1+2x)^3 - 1}{x} \\ \\
& \lim_{x \to \infty} \dfrac{40x^2 + 3}{5x^2 - x} \quad\quad \lim_{x \to \infty} \dfrac{3x^2 + 2}{4x^3 + x} \quad\quad \lim_{x \to \infty} \dfrac{10x^4 + x}{2x^4 - 5}
\end{align*}$$





puzzle: Rom 4
code: 1296
Q: Koden til neste rom er $(f'(2))^4$ for $$f(x) = \begin{cases} \dfrac{x^3 - 8}{x - 2} \quad \text{for} \quad x \neq 2 \\ \\ 12 \quad \text{for} \quad x = 2  \end{cases}$$





puzzle: Rom 5
code: 1024
Q: Koden til neste rom er summen av $k^{10}$ for alle $k$ som gjør funksjonen nedenfor kontinuerlig: $$f(x) = \begin{cases} \dfrac{x^3 - k^3}{x - k} \quad \text{for} \quad x \lt k \\ \\ 6x \quad \text{for} \quad x \geq k  \end{cases}$$



puzzle: Rom 6
code: 125
Q: Koden til neste rom er gitt ved $$\left(\ln (x_1) + \ln (x_2)\right)^3$$ der $x_1$ og $x_2$ er nullpunktene til funksjonen $$f(x) = (\ln x)^2 - 5 \ln x + 6$$






puzzle: Rom 7
code: 162
Q: En funksjon $f$ er gitt ved $f(x) = e^{2x}$. <br> <br> En tangent til grafen til $f$ er gitt ved $$y = a(x - \ln 3) + b$$ der $a$ og $b$ er konstanter. <br> <br> Koden til neste rom er $a \cdot b$.







puzzle: Rom 8
code: 216
Q: En funksjon $f$ er gitt ved $$f(x) = \begin{cases} \dfrac{x - 9}{\sqrt{x} - 3} \quad \text{hvis} \quad x \neq 9 \\ \\ a \quad \text{hvis} \quad x = 9 \end{cases}$$ der $a$ er en konstant. <br> <br> Koden til neste rom er verdien av $\dfrac{1}{(f'(9))^3}$ 





puzzle: Rom 9
code: 512
Q: En linje er gitt ved funksjonen $$f(x) = x - 2$$ <br><br> La $d$ være den korteste avstanden fra punktet $P(5, -1)$ til linja. Koden til neste rom er $d^6$. 



puzzle: Rom 10
code: 2048
Q: En funksjon $f$ er gitt ved $$f(x) = a^{\displaystyle \ln(x^b + 1)^{c}}$$ der $a$, $b$ og $c$ er konstanter. <br> <br> Den deriverte er gitt ved $$f'(x) = e^{\sqrt{\ln(x^4 + 1)}} \cdot \dfrac{1}{2\sqrt{\ln(x^4 + 1)}} \cdot \dfrac{1}{x^4 + 1} \cdot 4x^3$$ <br> <br> Koden for veien videre er $(\ln (a) \cdot b \cdot c)^{11}$

:::